ServiceLocator class

Constructors

ServiceLocator()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get<T extends Object>([String? name]) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerLazy<T extends Object>(T instance(), [String? name]) → void
registerLazySingleton<T extends Object>(T instance(), [String? name]) → void
registerSingleton<T extends Object>(T instance, [String? name]) → void
reset() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited