FakeRepository<T extends DataModel> mixin

Superclass constraints

Properties

fixtureFactory → FixtureFactory<T>
no setter
hashCode int
The hash code for this object.
no setterinherited
numberOfEntities int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(T entity) Future<T>
override
delete(int id) Future<void>
override
get(int id) Future<T>
override
getAll() Future<List<T>>
override
getAllForRelation<S extends DataModel>(S entity) Future<List<T>>
override
getAllForRelationById<S>(int id) Future<List<T>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(T entity) Future<T>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited